@@ -2,11 +2,12 @@ __author__ = "Swas.py"
 __title__ = "vscode"
 __license__ = "MIT"
 __copyright__ = "Copyright 2021 Swas.py"
-__version__ = "1.4.11"
+__version__ = "1.5.0"
 
 from . import window
-from .compiler import build
+from .compiler import build, build_theme
 from .extension import Extension
-from .envMethods import env
+from .themes import ColorTheme
+from .env_methods import env
 from . import types as ext
 from .types import *
